import store from '@/store'
import config from '@/config'
import {
    getTenantId,
    getToken
} from '@/utils/auth'
import errorCode from '@/utils/errorCode'
import {
    toast,
    showConfirm,
    tansParams
} from '@/utils/common'

let timeout = 10000
const baseUrl = config.baseUrl

const request = config => {
    // 是否需要设置 token
    const isToken = (config.headers || {}).isToken === false
    config.header = config.header || {}
    // config.header['tenant-id'] = '180'
    if (getToken() && !isToken) {
        config.header['Authorization'] = 'Bearer ' + getToken()
    }

    // get请求映射params参数
    if (config.params) {
        let url = config.url + '?' + tansParams(config.params)
        url = url.slice(0, -1)
        config.url = url
    }
    // 设置租户
    const isTanantId = (config.headers || {}).isTanantId === false
    config.header = config.header || {}
    // if (!config.hasOwnProperty("tenantIdFlag")) {
    //     //请求设置了不需要租户，不拼接，，走进这里的是没设置不需要租户的
    //     if (getTenantId() && !isTanantId) {
    //         config.header['tenant-id'] = getTenantId()
    //     }
    //     config.header['tenant-id'] = 180
    // }
    console.log(config.header, 424242);
    return new Promise((resolve, reject) => {
        uni.request({
            method: config.method || 'get',
            timeout: config.timeout || timeout,
            url: config.baseUrl || baseUrl + config.url,
            data: config.data,
            header: config.header,
            dataType: 'json'
        }).then(response => {
            // debugger
            let res = response

            const code = res.data.code || 200
            const msg = errorCode[code] || res.data.msg || errorCode['default']
            if (code === 401) {
                showConfirm('登录状态已过期，您可以继续留在该页面，或者重新登录?').then(res => {
                    if (res.confirm) {

                        console.log('跳转');
                        uni.reLaunch({
                            url: '/pages/login/login'
                        })

                    }
                })
                reject('无效的会话，或者会话已过期，请重新登录。')
            } else if (code === 500) {
                toast(msg)
                reject('500')
            } else if (code !== 200) {
                toast(msg)
                reject(code)
            }
            resolve(res.data)
        })
            .catch(error => {
                let {
                    message
                } = error
                if (message === 'Network Error') {
                    message = '后端接口连接异常'
                } else if (message.includes('timeout')) {
                    message = '系统接口请求超时'
                } else if (message.includes('Request failed with status code')) {
                    message = '系统接口' + message.substr(message.length - 3) + '异常'
                }
                toast(message)
                reject(error)
            })
    })
}

export default request
